Learn R Programming

rplec (version 0.1.3)

beta_v_indices: Indices for random beta values

Description

A list of indices for rand.idx in bmiq_norm_450k function. The input probes must be already filtered and ordered the same way to the that when we developed our placental epigenetic clock. Run data(probe_info_450k) and find the required probes in prob_info_450k$probeID.

Usage

beta_v_indices

Arguments

Format

A list of 2 elements where each has a length of nfit of 10000:

beta1.v

An integer indicating the selected indices.

beta2.v

An integer indicating the selected indices.