Learn R Programming

rplec (version 0.1.3)

bmiq_norm_450k: Normalize DNA methylation values

Description

This function normalize DNA methylation values from 450k probes. The probes are filtered and ordered the same way to the input when we developed our placental epigenetic clock.

Usage

bmiq_norm_450k(beta, cores = 1, verbose = FALSE)

Value

A data frame of normalized beta values.

Arguments

beta

A data frame of beta values where each column represents a sample and each row represent a probe. The rows must be named according to the probe IDs. They include all the required probes. Run data(probe_info_450k) and find the required probes in prob_info_450k$probeID. Meanwhile, the columns must be named according to the sample IDs.

cores

An integer indicating the number of threads.

verbose

A logical scalar indicating whether to show a progress bar.

Examples

Run this code

# \donttest{
  beta_values_case <- download_beta_values_case()
  norm_beta_values_case <- bmiq_norm_450k(beta_values_case)
# }

Run the code above in your browser using DataLab