Learn R Programming

rplec (version 0.1.3)

probe_info_450k: Probe info for 450K

Description

A list of 450K probe information for bmiq_norm_450k function. The probes are already filtered and ordered the same way to the input when we developed our placental epigenetic clock.

Usage

probe_info_450k

Arguments

Format

A list of 2 elements where each has a length of 346407:

Design

An integer indicating design type 1 or 2.

probeID

A character for each probe identifier.