A list of indices for rand.idx in bmiq_norm_450k function.
The input probes must be already filtered and ordered the same way to the
that when we developed our placental epigenetic clock. Run
data(probe_info_450k) and find the required probes in
prob_info_450k$probeID.
beta_v_indicesA list of 2 elements where each has a length of nfit of 10000:
An integer indicating the selected indices.
An integer indicating the selected indices.