This function normalize DNA methylation values from 450k probes. The probes
are filtered and ordered the same way to the input when we developed our
placental epigenetic clock.
Usage
bmiq_norm_450k(beta, cores = 1, verbose = FALSE)
Value
A data frame of normalized beta values.
Arguments
beta
A data frame of beta values where each column represents a
sample and each row represent a probe. The rows must be named according to
the probe IDs. They include all the required probes. Run
data(probe_info_450k) and find the required probes in
prob_info_450k$probeID. Meanwhile, the columns must be named according to
the sample IDs.
cores
An integer indicating the number of threads.
verbose
A logical scalar indicating whether to show a progress bar.